@@ -20,7 +20,6 @@ from canalyst_candas.utils import (
     read_json,
     save_guidance_csv,
     send_scenario,
-    get_excel_model,  # used externally
 )
 import __main__
 from pyvis.network import Network
@@ -695,7 +694,7 @@ class ModelSet:
         period_duration_type="",
         is_historical="",
         n_periods="",
-        mrq_notation=True,
+        mrq_notation=False,
         warning=True,
     ):
 
@@ -1267,7 +1266,7 @@ class Model:
         df = df.dropna(subset=["value"])
         # NEED TO ACCOUNT FOR EMPTY DATAFRAMES
         row1 = df.iloc[0]
-        title = row1["time_series_description"]
+        title = self.ticker + " " + row1["time_series_description"]
         xlabel = "Fiscal Quarter"
         ylabel = row1["time_series_description"]
         # plot data
@@ -1407,7 +1406,7 @@ class Model:
         df = self.gt.get_file(self.ticker, "model_drivers")
 
         if df is not None and force == False:
-            self.model_drivers = df
+            self._model_drivers = df
             return
         print("get drivers from model")
 
@@ -1427,10 +1426,10 @@ class Model:
         )
 
         df.columns = ["time_series_name"]
-        self.model_drivers = df
+        self._model_drivers = df
 
         ticker = self.ticker.split(" ")[0]
-        self.model_drivers.to_csv(
+        self._model_drivers.to_csv(
             f"{self.config.default_dir}/DATA/{ticker}/{self.ticker}_model_drivers.csv",
             index=False,
         )
@@ -1494,32 +1493,28 @@ class Model:
         return df
 
     def model_drivers(self, search_term=""):
-        df = self._modelframe
-        df_only_drivers = self.model_drivers
-        df_drivers = pd.merge(
+        mrq = self.mrq()["period_name"][0]
+        df = self._model_drivers
+        df2 = self._model_frame
+        df2 = df2.loc[df2["period_name"] == mrq]
+        df = pd.merge(
             df,
-            df_only_drivers,
+            df2,
             how="inner",
             left_on="time_series_name",
             right_on="time_series_name",
+        )[
+            ["name_index", "category", "time_series_name", "time_series_description"]
+        ].sort_values(
+            "name_index", ascending=True
         )
-        df1 = df[
-            df["time_series_description"].str.contains(
-                search_term, flags=re.IGNORECASE, regex=True
-            )
-        ]
-        df2 = df[
-            df["time_series_name"].str.contains(
-                search_term, flags=re.IGNORECASE, regex=True
-            )
-        ]
-        df = pd.concat([df1, df2])
-        df = (
-            df.groupby(["time_series_name", "time_series_description"])
-            .first()
-            .reset_index()
-        )
-        df = df[["time_series_name", "time_series_description"]]
+
+        if search_term != "":
+            df = df[
+                df["time_series_name"].str.contains(
+                    search_term, flags=re.IGNORECASE, regex=True
+                )
+            ]
         return df
 
     # MODELSET model_frame
@@ -1533,7 +1528,7 @@ class Model:
         period_duration_type="",
         is_historical="",
         n_periods=12,
-        mrq_notation=True,
+        mrq_notation=False,
         warning=True,
     ):
         return filter_dataset(
@@ -1557,11 +1552,11 @@ class Model:
         df = self.gt.get_file(self.ticker, "model_drivers")
 
         if df is not None and force == False:
-            self.model_drivers = df
+            self._model_drivers = df
         else:
             print("get driver library")
             self.get_driverlibrary(force=self.force)
-            df = self.model_drivers
+            df = self._model_drivers
 
         df = df.assign(is_driver=True)
         df2 = pd.merge(
@@ -1641,10 +1636,10 @@ class Model:
         return df
 
     def driver_search(self, search_term=""):
-        df = self.model_drivers
+        df = self._model_drivers
         if search_term != "":
             df = self._model_frame
-            df_only_drivers = self.model_drivers
+            df_only_drivers = self._model_drivers
             df_drivers = pd.merge(
                 df,
                 df_only_drivers,
@@ -1676,7 +1671,7 @@ class Model:
         #    return self.describe_drivers
         # get the historical dataframe from candas
         df = self.historical_data_frame()
-        df_only_drivers = self.model_drivers
+        df_only_drivers = self._model_drivers
         # merge the drivers and the historical data... and return a description of the values for each
         df_drivers = pd.merge(
             df,
