@@ -1060,8 +1060,14 @@ def json_to_df(dict_json, ticker):
 
 
 def mrq_df(df):
-    df["n"] = df.groupby(["ticker", "time_series_name"]).cumcount() + 1
-    df["n"] = "MRQ+" + df["n"].astype(str)
+    df = df[df["is_historical"] == True]
+
+    n_size = df.groupby(["ticker", "time_series_name"]).size().mean()
+    df["n"] = df.groupby(["ticker", "time_series_name"]).cumcount() - (n_size - 1)
+    df["n"] = df["n"].astype(int)
+
+    cols = list(df.groupby("n").first().reset_index()["n"])
+
     df = pd.pivot_table(
         df,
         values="value",
@@ -1072,11 +1078,29 @@ def mrq_df(df):
             "time_series_name",
             "time_series_description",
             "is_driver",
+            "MRQ",
         ],
         columns=["n"],
         aggfunc=np.sum,
     ).reset_index()
+    list_cols = []
 
+    name_cols = [
+        "name_index",
+        "ticker",
+        "category",
+        "time_series_name",
+        "time_series_description",
+        "is_driver",
+        "MRQ",
+    ]
+
+    col_names = []
+    for col in df.columns:
+        if col not in name_cols:
+            col = "MRQ" + str(col)
+            col_names.append(col)
+    df.columns = name_cols + col_names
     return df.sort_values("name_index")
 
 
